@@ -1027,7 +1027,7 @@ class TestEvaluateDecoratorAsync:
         delay = 0.1  # 100ms delay per sample
         num_func_calls = 0
         # Allow some buffer for overhead; still much lower than sequential execution (5s)
-        max_concurrent_duration = 1  # 1 second max for all calls
+        max_concurrent_duration = 2  # 2 seconds max for all calls
 
         @evaluate(
             test_cases=[TestCase(id="timing_test", input="test")],
